#!/usr/bin/env python3

# DO NOT use any python features here that require 3.6 or newer


def setup_requires():
    return [
        'setuptools',
        'wheel',
        'pytest-runner>=2.9',
        'packaging',
    ]


install_requires = [
    'rdflib>=6.0.0,<7.0.0',
    'graphviz==0.17',
    'typer',
    'rich',
    'matplotlib',
] + setup_requires()
# {package_name: "description"}
install_suggests = {}
doc_requires = [
    'sphinx',
    'python-slugify',
    'myst-nb>=0.13.1',
    'sphinx-autoapi>=1.8',
] + install_requires
ci_requires = [
    'pytest',
    'pytest-cov',
    'pytest-xdist',
    'check-manifest',
    'black',
    'pre-commit',
    'autopep8',
    'pytest-pycharm',
    'readme_renderer[md]',
    'rstcheck',
    'codecov',
    'twine',
    'pytest-memprof',
    'pytest-regressions',
    'pytest-datadir',
    'pytest-timeout',
    'docutils',
]
# these don't go into the pip extras
optional_requirements_file_only = []


def strip_markers(name):
    for m in ';<>=':
        try:
            i = name.index(m)
            name = name[:i].strip()
        except ValueError:
            continue
    return name


def extras():
    import pkg_resources
    import itertools

    def _candidates(blocklist):
        # skip those which aren't needed in our current environment (py ver, platform)
        for pkg in set(itertools.chain(doc_requires, install_suggests.keys())):
            if pkg in blocklist:
                continue
            try:
                marker = next(pkg_resources.parse_requirements(pkg)).marker
                if marker is None or marker.evaluate():
                    yield pkg
            except pkg_resources.RequirementParseError:
                # try to fake a package to get the marker parsed
                stripped = strip_markers(pkg)
                fake_pkg = 'pip ' + pkg.replace(stripped, '')
                try:
                    marker = next(pkg_resources.parse_requirements(fake_pkg)).marker
                    if marker is None or marker.evaluate():
                        yield pkg
                except pkg_resources.RequirementParseError:
                    continue

    # blocklisted packages need a (minimal) compiler setup
    # - nbresuse, pytest-memprof depend on psutil which has no wheels
    return {
        'ci': ci_requires,
        'docs': doc_requires,
        'full': list(install_suggests.keys()) + ci_requires + doc_requires,
    }


toml_tpl = '''
[tool.black]
line-length = 120
skip-string-normalization = true

[build-system]
requires = {0}
build-backend = "setuptools.build_meta"
'''
if __name__ == '__main__':
    note = '# This file is autogenerated. Edit dependencies.py instead'
    print(' '.join([i for i in install_requires + list(install_suggests.keys())]))
    import os
    import itertools

    with open(os.path.join(os.path.dirname(__file__), 'requirements.txt'), 'wt') as req:
        req.write(note + '\n')
        for module in sorted(set(itertools.chain(install_requires, setup_requires()))):
            req.write(module + '\n')
    with open(os.path.join(os.path.dirname(__file__), 'requirements-optional.txt'), 'wt') as req:
        req.write(note + '\n')
        req.write('-r requirements.txt\n')
        req.write('-r requirements-ci.txt\n')
        for module in sorted(
            set(itertools.chain(optional_requirements_file_only, doc_requires, install_suggests.keys()))
        ):
            req.write(module + '\n')
    with open(os.path.join(os.path.dirname(__file__), 'requirements-ci.txt'), 'wt') as req:
        req.write('-r requirements.txt\n')
        req.write(note + '\n')
        for module in sorted(ci_requires):
            req.write(module + '\n')
    with open(os.path.join(os.path.dirname(__file__), 'pyproject.toml'), 'wt') as toml:
        toml.write(note)
        toml.write(toml_tpl.format(str(setup_requires())))



import argparse

from ontoviz.graph import OntologyGraph
from ontoviz.utils import Config


def main():
    parser = argparse.ArgumentParser(description='Generate dot for the input ontology files')
    parser.add_argument('files', nargs='+', help='Input ontology files.')
    parser.add_argument('-f', '--format', dest='format', default='ttl', help='Input file format.')
    parser.add_argument('-o', '--output', dest='out', default='ontology.dot', help='Location of output dot file.')
    parser.add_argument('-O', '--ontology', dest='ontology', default=None, help='Provided ontology for the graph.')
    parser.add_argument('-C', '--config', dest='config', default=None, help='Provided configuration.')
    args = parser.parse_args()

    config = Config(args.config)
    og = OntologyGraph(args.files, config, args.format, ontology=args.ontology)
    og.write_file(args.out)


if __name__ == '__main__':
    main()



from rdflib import URIRef
from rdflib.namespace import Namespace
import re


SCHEMA = Namespace('http://schema.org/')


class Colors:
    cls = '#1f77b4'
    lit = '#ff7f0e'
    ins = '#e377c2'
    filled = True


class Config:
    def __init__(self, config_file=None):
        self.blacklist = set()
        self.class_inference_in_object = set()
        self.property_inference_in_object = set()
        self.max_label_length = 0
        self.label_property = set()
        self.tooltip_property = set()
        self.bnode_regex = list()
        self.colors = Colors()
        if config_file:
            self.read_config_file(config_file)

    def read_config_file(self, config_file):
        import json

        with open(config_file) as f:
            config = json.load(f)
            self.blacklist = {URIRef(x) for x in config.get('blacklist', [])}
            self.class_inference_in_object = {URIRef(x) for x in config.get('class_inference_in_object', [])}
            self.property_inference_in_object = {URIRef(x) for x in config.get('property_inference_in_object', [])}
            self.max_label_length = int(config.get('max_label_length', 0))
            self.label_property = {URIRef(x) for x in config.get('label_property', [])}
            self.tooltip_property = {URIRef(x) for x in config.get('tooltip_property', [])}
            self.bnode_regex = [re.compile(pattern) for pattern in config.get('bnode_regex', [])]
        if 'colors' in config:
            config_color = ConfigColor()
            colors = config['colors']
            self.colors.cls = config_color.parse(colors.get('class', self.colors.cls), self.colors.cls)
            self.colors.lit = config_color.parse(colors.get('literal', self.colors.lit), self.colors.lit)
            self.colors.ins = config_color.parse(colors.get('instance', self.colors.ins))
            self.colors.filled = colors.get('filled', True)

    def get_ins_color(self, cls):
        if isinstance(self.colors.ins, dict):
            return self.colors.ins.get(str(cls), self.colors.ins['default'])
        return self.colors.ins

    def get_cls_color(self, cls):
        if isinstance(self.colors.cls, dict):
            return self.colors.cls.get(str(cls), self.colors.cls['default'])
        return self.colors.cls

    def bnode_regex_match(self, uri):
        for pattern in self.bnode_regex:
            if pattern.match(uri):
                return True
        return False


class UndefinedColorError(Exception):
    pass


class ConfigColor:
    default_color_map = {
        'y': '#ffff00',  # yellow
        'yellow': '#ffff00',
        'm': '#ff00ff',  # magenta
        'magenta': '#ff00ff',
        'c': '#00ffff',  # cyan
        'cyan': '#00ffff',
        'r': '#ff0000',  # red
        'red': '#ff0000',
        'g': '#00ff00',  # green
        'green': '#00ff00',
        'b': '#0000ff',  # blue
        'blue': '#0000ff',
        'w': '#ffffff',  # white
        'white': '#ffffff',
        'k': '#000000',  # black
        'black': '#000000',
    }

    def parse(self, s, default='y'):
        if isinstance(s, dict):
            if 'default' not in s:
                s['default'] = default
            return {cls: self.parse(color) for cls, color in s.items()}
        if s.startswith('#'):
            return s
        if s in self.default_color_map:
            return self.default_color_map[s]
        else:
            raise UndefinedColorError("UndefinedColorError: %s isn't defined.", s)
